@@ -26,8 +26,8 @@
 
 #include "config.h"
 
-#include "galias.h"
 #include "glib.h"
+#include "galias.h"
 
 
 G_LOCK_DEFINE_STATIC (queue_memchunk);
@@ -53,8 +53,8 @@ g_queue_new (void)
     {
       if (!queue_memchunk)
 	queue_memchunk = g_mem_chunk_new ("GLib GQueue chunk",
-					  sizeof (GNode),
-					  sizeof (GNode) * 128,
+					  sizeof (GQueue),
+					  sizeof (GQueue) * 128,
 					  G_ALLOC_ONLY);
       queue = g_chunk_new (GQueue, queue_memchunk);
     }
@@ -229,8 +229,8 @@ g_queue_find (GQueue        *queue,
  * Finds an element in a #GQueue, using a supplied function to find the
  * desired element. It iterates over the queue, calling the given function
  * which should return 0 when the desired element is found. The function
- * takes two gconstpointer arguments, the #GQueue element's data and the
- * given user data.
+ * takes two gconstpointer arguments, the #GQueue element's data as the
+ * first argument and the given user data as the second argument.
  * 
  * Return value: The found link, or %NULL if it wasn't found
  * 
@@ -730,7 +730,7 @@ gint
 g_queue_link_index (GQueue *queue,
 		    GList  *link_)
 {
-  g_return_val_if_fail (queue != NULL, 0);
+  g_return_val_if_fail (queue != NULL, -1);
 
   return g_list_position (queue->head, link_);
 }
@@ -975,7 +975,7 @@ g_queue_insert_after (GQueue   *queue,
  *     called with two elements of the @queue and @user_data. It should
  *     return 0 if the elements are equal, a negative value if the first
  *     element comes before the second, and a positive value if the second
- *     element comes after the first.
+ *     element comes before the first.
  * @user_data: user data passed to @func.
  * 
  * Inserts @data into @queue using @func to determine the new position.
@@ -1001,3 +1001,6 @@ g_queue_insert_sorted (GQueue           *queue,
   else
     g_queue_push_tail (queue, data);
 }
+
+#define __G_QUEUE_C__
+#include "galiasdef.c"
